@@ -423,17 +423,6 @@ op_cut (HTMLObject *self, HTMLEngine *e, GList *from, GList *to, GList *left, GL
 		return cut_whole (self, len);
 }
 
-static gboolean
-cell_is_empty (HTMLTableCell *cell)
-{
-	g_assert (HTML_IS_TABLE_CELL (cell));
-
-	if (HTML_CLUE (cell)->head && HTML_CLUE (cell)->head == HTML_CLUE (cell)->tail
-	    && HTML_IS_CLUEFLOW (HTML_CLUE (cell)->head) && html_clueflow_is_empty (HTML_CLUEFLOW (HTML_CLUE (cell)->head)))
-		return TRUE;
-	return FALSE;
-}
-
 static void
 split (HTMLObject *self, HTMLEngine *e, HTMLObject *child, gint offset, gint level, GList **left, GList **right)
 {
@@ -452,7 +441,7 @@ split (HTMLObject *self, HTMLEngine *e, HTMLObject *child, gint offset, gint lev
 	dup_cell  = HTML_TABLE_CELL ((*right)->data);
 	cell      = HTML_TABLE_CELL ((*left)->data);
 
-	if (dup_cell->row == t->totalRows - 1 && dup_cell->col == t->totalCols - 1 && cell_is_empty (dup_cell)) {
+	if (dup_cell->row == t->totalRows - 1 && dup_cell->col == t->totalCols - 1 && html_clue_is_empty (HTML_CLUE (dup_cell))) {
 		dup = html_engine_new_text_empty (e);
 		html_object_destroy ((*right)->data);
 		g_list_free (*right);
@@ -569,10 +558,10 @@ could_merge (HTMLTable *t1, HTMLTable *t2)
 				return FALSE;
 
 			if (first) {
-				if (!cell_is_empty (c2))
+				if (!html_clue_is_empty (HTML_CLUE (c2)))
 					first = FALSE;
 			} else {
-				if (!cell_is_empty (c1))
+				if (!html_clue_is_empty (HTML_CLUE (c1)))
 					return FALSE;
 			}
 		}
@@ -662,9 +651,9 @@ merge (HTMLObject *self, HTMLObject *with, HTMLEngine *e, GList **left, GList **
 			c2 = t2->cells [r][c];
 
 			if (first) {
-				if (!cell_is_empty (c2)) {
+				if (!html_clue_is_empty (HTML_CLUE (c2))) {
 					t1_tail = prev_c1;
-					if (cell_is_empty (c1)) {
+					if (html_clue_is_empty (HTML_CLUE (c1))) {
 						move_cell (t1, t2, c1, c2, cursor_cell_1, cursor_cell_2,
 							   r, c, e->cursor, cursor);
 						c1 = c2;
@@ -1016,7 +1005,9 @@ calc_row_heights (HTMLTable *table,
 					ROW_HEIGHT (table, rl) = height;
 			}
 		}
+		/* printf ("height %d: %d\n", r, ROW_HEIGHT (table, r)); */
 	}
+	/* printf ("height %d: %d\n", r, ROW_HEIGHT (table, r)); */
 }
 
 static void
@@ -1048,6 +1039,7 @@ html_table_set_cells_position (HTMLTable *table, HTMLPainter *painter)
 				HTML_OBJECT (cell)->x = COLUMN_OPT (table, c) + pixel_size * border_extra;
 				HTML_OBJECT (cell)->y = ROW_HEIGHT (table, rl) + pixel_size * (- table->spacing)
 					- HTML_OBJECT (cell)->descent;
+				/* printf ("y: %d\n", HTML_OBJECT (cell)->y); */
 				html_object_set_max_height (HTML_OBJECT (cell), painter,
 							    ROW_HEIGHT (table, rl) - ROW_HEIGHT (table, cell->row)
 							    - pixel_size * (table->spacing + border_extra));
@@ -1084,7 +1076,7 @@ html_table_set_max_height (HTMLObject *o, HTMLPainter *painter, gint height)
 }
 
 static gboolean
-calc_size (HTMLObject *o, HTMLPainter *painter, GList **changed_objs)
+html_table_real_calc_size (HTMLObject *o, HTMLPainter *painter, GList **changed_objs)
 {
 	HTMLTable *table = HTML_TABLE (o);
 	gint old_width, old_ascent, pixel_size;
@@ -1306,7 +1298,8 @@ calc_min_width (HTMLObject *o,
 {
 	HTMLTable *table = HTML_TABLE (o);
 
-	calc_column_width_template (table, painter, table->columnMin, html_object_calc_min_width, table->columnMin);
+	calc_column_width_template (table, painter, table->columnPref, html_object_calc_preferred_width, table->columnPref);
+	calc_column_width_template (table, painter, table->columnMin, html_object_calc_min_width, table->columnPref);
 
 	return o->flags & HTML_OBJECT_FLAG_FIXEDWIDTH
 		? MAX (html_painter_get_pixel_size (painter) * table->specified_width,
@@ -1319,15 +1312,17 @@ calc_preferred_width (HTMLObject *o,
 		      HTMLPainter *painter)
 {
 	HTMLTable *table = HTML_TABLE (o);
+	int min_width;
+
+	/* note that calculating min width prepares columnPref for us */
+	min_width = html_object_calc_min_width (o, painter);
 
-	calc_column_width_template (table, painter, table->columnPref,
-				    html_object_calc_preferred_width, table->columnPref);
 	calc_column_width_template (table, painter, table->columnFixed,
 				    (gint (*)(HTMLObject *, HTMLPainter *)) html_table_cell_get_fixed_width,
 				    table->columnPref);
 
 	return o->flags & HTML_OBJECT_FLAG_FIXEDWIDTH
-		? MAX (html_painter_get_pixel_size (painter) * table->specified_width, html_object_calc_min_width (o, painter))
+		? MAX (html_painter_get_pixel_size (painter) * table->specified_width, min_width)
 		: COLUMN_PREF (table, table->totalCols) + table->border * html_painter_get_pixel_size (painter);
 }
 
@@ -2140,7 +2135,7 @@ save (HTMLObject *self,
 		}
 		SB "</TR>\n" SE;
 	}
-	SB "</TABLE>\n" SE;
+	SB "</TABLE>" SE;
 
 	return TRUE;
 }
@@ -2171,7 +2166,7 @@ save_plain (HTMLObject *self,
 }
 
 static gboolean
-check_row_split (HTMLTable *table, gint r, gint *min_y)
+check_row_split (HTMLTable *table, HTMLPainter *painter, gint r, gint *min_y)
 {
 	HTMLTableCell *cell;
 	gboolean changed = FALSE;
@@ -2188,8 +2183,8 @@ check_row_split (HTMLTable *table, gint r, gint *min_y)
 		y2 = HTML_OBJECT (cell)->y + HTML_OBJECT (cell)->descent;
 
 		if (y1 <= *min_y && *min_y < y2) {
-			cs = html_object_check_page_split (HTML_OBJECT (cell), *min_y - y1) + y1;
-			/* printf ("min_y: %d y1: %d y2: %d --> cs=%d\n", *min_y, y1, y2, cs); */
+			cs = html_object_check_page_split (HTML_OBJECT (cell), painter, *min_y - y1) + y1;
+			/* printf ("r %d min_y: %d y1: %d y2: %d --> cs=%d\n", *min_y, y1, y2, cs); */
 
 			if (cs < *min_y) {
 				*min_y = cs;
@@ -2202,10 +2197,10 @@ check_row_split (HTMLTable *table, gint r, gint *min_y)
 }
 
 static gint
-check_page_split (HTMLObject *self, gint y)
+check_page_split (HTMLObject *self, HTMLPainter *painter, gint y)
 {
 	HTMLTable     *table;
-	gint r, min_y;
+	int r, min_y;
 
 	table = HTML_TABLE (self);
 	r     = to_index (bin_search_index (table->rowHeights, 0, table->totalRows, y), 0, table->totalRows - 1);
@@ -2218,7 +2213,7 @@ check_page_split (HTMLObject *self, gint y)
 	   return MIN (y, ROW_HEIGHT (table, table->totalRows)); */
 
 	min_y = MIN (y, ROW_HEIGHT (table, r+1));
-	while (check_row_split (table, r, &min_y));
+	while (check_row_split (table, painter, r, &min_y));
 
 	/* printf ("min_y=%d\n", min_y); */
 
@@ -2259,7 +2254,7 @@ html_table_class_init (HTMLTableClass *klass,
 	object_class->split = split;
 	object_class->merge = merge;
 	object_class->accepts_cursor = accepts_cursor;
-	object_class->calc_size = calc_size;
+	object_class->calc_size = html_table_real_calc_size;
 	object_class->draw = draw;
 	object_class->destroy = destroy;
 	object_class->calc_min_width = calc_min_width;
